#include "Global.h"
#include "Util.h"
#include "Object.h"
#include "Interface.h"
#include "Creature.h"
#include "Hero.h"

extern int useOnOffTool (shObject *tool);
extern int useEnergyTank (shObject *tank);

static int
switchMaskMode (shObject *mask)
{
    if (mask->isToggled ()) {
        I->p ("You switch %s to thermal vision mode.", YOUR (mask));
        mask->resetToggled ();
    } else {
        I->p ("You switch %s to EM field vision mode.", YOUR (mask));
        mask->setToggled ();
    }
    Hero.computeIntrinsics ();
    return HALFTURN;
}

void
initializeArmor ()
{
    /* enum: kObjAnyArmor */
    /* enum: kObjFirstArmor = kObjAnyArmor */
    NEW_ARMOR(kObjAnyArmor,
        "armor piece", "armor piece", "armor piece",
        kGray, kObjNothing, kSteel,
        kEnhanceable, 1000, kTiny, 20, 10, 0,
        0, 0, kNoEnergy, 0, 0, 0, 0 BZ, ABSTRACT);

    /* enum: kObjGenericHelmet */
    NEW_ARMOR(kObjGenericHelmet,
        "helmet", "helmet", "helmet",
        kGray, kObjAnyArmor, kSteel,
        kEnhanceable, 400, kTiny, 20, 10, 0,
        0, 2, kNoEnergy, 0, 0, 0, 0 BZ, ABSTRACT);

    /* enum: kObjKevlarHelmet */
    NEW_ARMOR(kObjKevlarHelmet,
        "kevlar helmet", "helmet", "heavy helmet",
        kBrown, kObjGenericHelmet, kCloth,
        kEnhanceable, 1200, kTiny, 20, 10, -1,
        1, 2, kPiercing, 1, 2000, 0, 125 BZ, 25);

    /* enum: kObjStormtrooperHelmet */
    NEW_ARMOR(kObjStormtrooperHelmet,
        "stormtrooper helmet", "helmet", "plastic helmet",
        kWhite, kObjGenericHelmet, kPlastic,
        kEnhanceable | kSealed, 1000, kTiny, 20, 10, -1,
        1, 2, kNoEnergy, 0, 2000, 5, 50 BZ, 25);
    AllIlks[kObjStormtrooperHelmet]->mWornIntrinsics |= kAirSupply;
    AllIlks[kObjStormtrooperHelmet]->mToHitModifier = -2;

    /* enum: kObjSpaceHelmet */
    NEW_ARMOR(kObjSpaceHelmet,
        "space helmet", "helmet", "sealed helmet",
        kWhite, kObjGenericHelmet, kSteel,
        kEnhanceable | kSealed, 2000, kTiny, 20, 10, -1,
        1, 2, kNoEnergy, 20, 2000, 5, 100 BZ, 25);
    AllIlks[kObjSpaceHelmet]->mWornIntrinsics |= kAirSupply;

    /* enum: kObjFootballHelmet */
    NEW_ARMOR(kObjFootballHelmet,
        "football helmet", "helmet", "padded helmet",
        kRed, kObjGenericHelmet, kSteel,
        kEnhanceable, 4000, kTiny, 20, 10, 0,
        1, 2, kNoEnergy, 0, 1500, 5, 25 BZ, 3);

    /* enum: kObjEnergyDome */
    NEW_ARMOR(kObjEnergyDome,
        "energy dome", "helmet", "flowerpot",
        kYellow, kObjGenericHelmet, kPlastic,
        kEnhanceable, 25, kTiny, 20, 10, +4,
        1, 3, kNoEnergy, 0, 1500, 5, 25 BZ, 5);

    /* enum: kObjHarmonyDome */
    /* Note its psi modifier is applied only when buggy. */
    /* Implemented in Object.cpp getPsiModifier (). */
    NEW_ARMOR(kObjHarmonyDome,
        "harmony dome", "helmet", "flowerpot",
        kBrightGreen, kObjGenericHelmet, kPlastic,
        kEnhanceable, 25, kTiny, 20, 10, -8,
        1, 3, kNoEnergy, 0, 1500, 5, 25 BZ, 5);

    /* enum: kObjBrainShield */
    NEW_ARMOR(kObjBrainShield,
        "brain shield", "hat", "tinfoil hat",
        kCyan, kObjGenericHelmet, kSteel,
        kEnhanceable, 25, kTiny, 20, 10, -20,
        0, 2, kNoEnergy, 0, 1500, 5, 25 BZ, 5);
    AllIlks[kObjBrainShield]->mWornIntrinsics |= kReflection | kBrainShielded;

    /* enum: kObjAquamarinePH */
    NEW_ARMOR(kObjAquamarinePH,
        "aquamarine power helmet", "armored helmet", "aqua rounded helmet",
        kBrightCyan, kObjGenericHelmet, kPlasteel,
        kEnhanceable | kPowered | kSealed, 1000, kSmall, 20, 10, -1,
        2, 2, kBlinding, 10, 2000, 0, 500 BZ, 10);
    AllIlks[kObjAquamarinePH]->mWornIntrinsics |= kAirSupply;

    /* enum: kObjMeanGreenPH */
    NEW_ARMOR(kObjMeanGreenPH,
        "mean green power helmet", "armored helmet", "green rounded helmet",
        kGreen, kObjGenericHelmet, kPlasteel,
        kEnhanceable | kPowered | kSealed, 1000, kSmall, 20, 10, -1,
        2, 2, kBlinding, 10, 2000, 0, 500 BZ, 10);
    AllIlks[kObjMeanGreenPH]->mWornIntrinsics |= kAirSupply;

    /* enum: kObjBrotherhoodPH */
    // Adds +1 to cha (see ApplyConferredResistances)
    NEW_ARMOR(kObjBrotherhoodPH,
        "brotherhood power helmet", "armored helmet", "rounded helmet",
        kWhite, kObjGenericHelmet, kSteel,
        kEnhanceable | kPowered | kSealed, 1000, kSmall, 20, 10, -1,
        2, 2, kRadiological, 5, 2000, 0, 500 BZ, 7);
    AllIlks[kObjBrotherhoodPH]->mWornIntrinsics |= kAirSupply;

    /* enum: kObjElvenCombatHelmet */
    shObjectIlk *ech =
    NEW_ARMOR(kObjElvenCombatHelmet,
        "elven combat helmet", "pointy helmet", "pointy pink helmet",
        kMagenta, kObjGenericHelmet, kBone,
        kEnhanceable | kSealed, 750, kTiny, 15, 15, +1,
        2, 2, kPsychic, 2, 1000, 0, 100 BZ, 15);
    ech->mWornIntrinsics |= kAirSupply;

    /* enum: kObjElvenExarchHelmet */
    shObjectIlk *exh =
    NEW_ARMOR(kObjElvenExarchHelmet,
        "elven exarch helmet", "pointy helmet", "pointy pink helmet",
        kMagenta, kObjGenericHelmet, kBone,
        kEnhanceable | kSealed, 900, kTiny, 15, 15, +1,
        1, 2, kPsychic, 3, 1500, 0, 300 BZ, 5);
    exh->mWornIntrinsics |= kAirSupply;
    exh->mSpeedBoost = 5;

    /* enum: kObjBioMask */
    NEW_ARMOR(kObjBioMask,
        "bio-mask", "mask", "bio-mask",
        kRed, kObjGenericHelmet, kCarbonFiber,
        kEnhanceable, 800, kSmall, 12, 10, 0,
        1, 2, kNoEnergy, 0, 3000, 0, 1150 BZ, 1);
    AllIlks[kObjBioMask]->mToHitModifier = 3;
    AllIlks[kObjBioMask]->mWornIntrinsics |= kAirSupply | kTranslation;
    AllIlks[kObjBioMask]->mUseFunc = switchMaskMode;

    /* enum: kObjGenericGoggles */
    NEW_ARMOR(kObjGenericGoggles,
        "pair of goggles", "pair of goggles", "pair of goggles",
        kGray, kObjAnyArmor, kPlastic,
        0, 50, kTiny, 20, 10, 0,
        0, 0, kNoEnergy, 0, 0, 0, 0, ABSTRACT);

    /* enum: kObjSunglasses */
    NEW_ARMOR(kObjSunglasses,
        "pair of sunglasses", "pair of goggles", "pair of goggles",
        kYellow, kObjGenericGoggles, kPlastic,
        0, 50, kTiny, 5, 1, 0,
        0, 0, kBlinding, 100, 500, 0, 50 BZ, 10);

    /* enum: kObjPerilGoggles */
    shObjectIlk *pss =
    NEW_ARMOR(kObjPerilGoggles,
        "pair of peril-sensitive sunglasses", "pair of goggles",
        "pair of goggles",
        kYellow, kObjGenericGoggles, kPlastic,
        kUsuallyBuggy, 50, kTiny, 5, 1, 0,
        0, 0, kBlinding, 100, 500, 0, 50 BZ, 10);
    pss->mWornIntrinsics |= kPerilSensing;

    /* enum: kObjBlindfold */
    NEW_ARMOR(kObjBlindfold,
        "blindfold", "blindfold", "blindfold",
        kBrightBlue, kObjGenericGoggles, kCloth,
        kPreidentified, 50, kTiny, 20, 5, 0,
        0, 0, kBlinding, 100, 500, 0, 50 BZ, 10);
    AllIlks[kObjBlindfold]->mWornIntrinsics |= kBlind;

    /* enum: kObjXRayGoggles */
    shObjectIlk *xraygoggles =
    NEW_ARMOR(kObjXRayGoggles,
        "pair of x-ray goggles", "pair of goggles", "pair of goggles",
        kRed, kObjGenericGoggles, kPlastic,
        0, 50, kTiny, 20, 5, 0,
        0, 0, kNoEnergy, 0, 500, 0, 100 BZ, 10);
    xraygoggles->mWornIntrinsics |= kXRayVision;

    /* enum: kObjTargeterGoggles */
    shObjectIlk *targeter =
    NEW_ARMOR(kObjTargeterGoggles,
        "pair of targeter goggles", "pair of goggles", "pair of goggles",
        kRed, kObjGenericGoggles, kPlastic,
        0, 50, kTiny, 20, 5, 0,
        0, 0, kNoEnergy, 0, 500, 0, 100 BZ, 10);
    targeter->mToHitModifier = 2;
    targeter->mDamageModifier = 2;

    /* enum: kObjNVGoggles */
    shObjectIlk *infragoggles =
    NEW_ARMOR(kObjNVGoggles,
        "pair of night vision goggles", "pair of goggles", "pair of goggles",
        kRed, kObjGenericGoggles, kPlastic,
        0, 50, kTiny, 20, 5, 0,
        0, 0, kNoEnergy, 0, 500, 0, 100 BZ, 10);
    infragoggles->mWornIntrinsics |= kNightVision;

    /* enum: kObjScouterGoggles */
    /* Handled in look at monster routine in shHero::takeTurn (). */
    NEW_ARMOR(kObjScouterGoggles,
        "pair of scouter goggles", "pair of goggles", "pair of goggles",
        kRed, kObjGenericGoggles, kPlastic,
        0, 50, kTiny, 20, 5, 0,
        0, 0, kNoEnergy, 0, 500, 0, 100 BZ, 10);


    /* enum: kObjGenericBelt */
    NEW_ARMOR(kObjGenericBelt,
        "belt", "belt", "belt",
        kGray, kObjAnyArmor, kSteel,
        kPreidentified, 400, kTiny, 20, 10, 0,
        0, 0, kNoEnergy, 0, 0, 0, 0 BZ, ABSTRACT);

    int n = 0;
    /* enum: kObjShieldBelt */
    NEW_ARMOR(kObjShieldBelt,
        "shield belt", "belt", BeltData[n].mDesc,
        BeltData[n].mColor, kObjGenericBelt, kSteel,
        0, 100, kTiny, 4, 1, 0,
        0, 0, kNoEnergy, 0, 500, 0, 300 BZ, 10);
    AllIlks[kObjShieldBelt]->mActiveIntrinsics |= kShielded;
    AllIlks[kObjShieldBelt]->mUseFunc = useOnOffTool;
    ++n;

    /* enum: kObjArmoredBelt */
    NEW_ARMOR(kObjArmoredBelt,
        "armored belt", "belt", BeltData[n].mDesc,
        BeltData[n].mColor, kObjGenericBelt, kSteel,
        0, 100, kTiny, 15, 1, 0,
        1, 0, kNoEnergy, 0, 100, 0, 300 BZ, 10);
    ++n;

    /* enum: kObjEnergyBelt */
    NEW_ARMOR(kObjEnergyBelt,
        "energy belt", "belt", BeltData[n].mDesc,
        BeltData[n].mColor, kObjGenericBelt, kSteel,
        0, 100, kTiny, 4, 1, 0,
        0, 0, kNoEnergy, 0, 100, 0, 300 BZ, 10);
    AllIlks[kObjEnergyBelt]->mMaxCharges = 100;
    AllIlks[kObjEnergyBelt]->mFlags |= kChargeable;
    AllIlks[kObjEnergyBelt]->mUseFunc = useEnergyTank;
    ++n;

    /* enum: kObjFashionBelt */
    NEW_ARMOR(kObjFashionBelt,
        "fashionable belt", "belt", BeltData[n].mDesc,
        BeltData[n].mColor, kObjGenericBelt, kSteel,
        kUsuallyBuggy, 100, kTiny, 4, 1, 0,
        0, 0, kNoEnergy, 0, 100, 0, 300 BZ, 10);
    ++n;

    /* enum: kObjCloakingBelt */
    NEW_ARMOR(kObjCloakingBelt,
        "cloaking belt", "belt", BeltData[n].mDesc,
        BeltData[n].mColor, kObjGenericBelt, kSteel,
        0, 100, kTiny, 4, 1, 0,
        0, 0, kNoEnergy, 0, 500, 0, 300 BZ, 10);
    AllIlks[kObjCloakingBelt]->mActiveIntrinsics |= kInvisible;
    AllIlks[kObjCloakingBelt]->mUseFunc = useOnOffTool;
    AllIlks[kObjCloakingBelt]->mEnergyUse = 250; /* 4 cells/turn */

    /* enum: kObjGenericCloak */
    NEW_ARMOR(kObjGenericCloak,
        "cloak", "cloak", "cloak",
        kGray, kObjAnyArmor, kCloth,
        kEnhanceable, 400, kMedium, 10, 5, 0,
        0, 2, kNoEnergy, 0, 0, 0, 0 BZ, ABSTRACT);

    /* enum: kObjAdamantineCloak */
    NEW_ARMOR(kObjAdamantineCloak,
        "adamantine cloak", "metallic cloak", "heavy cloak",
        kGray, kObjGenericCloak, kAdamantium,
        kEnhanceable, 4000, kLarge, 25, 5, -4,
        2, 2, kSlashing, 3, 3000, 5, 330 BZ, 2);
    AllIlks[kObjAdamantineCloak]->mToHitModifier = -3; //it's heavy!

    /* enum: kObjBadassTrenchcoat */
    NEW_ARMOR(kObjBadassTrenchcoat,
        "badass trenchcoat", "trenchcoat", "trenchcoat",
        kBrown, kObjGenericCloak, kCloth,
        kEnhanceable, 3000, kLarge, 10, 5, 0,
        1, 2, kNoEnergy, 0, 2000, 0, 120 BZ, 4);
    AllIlks[kObjBadassTrenchcoat]->mToHitModifier = +2;

    /* enum: kObjLoserAnorak */
    NEW_ARMOR(kObjLoserAnorak,
        "loser anorak", "trenchcoat", "trenchcoat",
        kBrown, kObjGenericCloak, kPlastic,
        kEnhanceable | kUsuallyBuggy, 2000, kLarge, 2, 2, -1,
        1, 2, kViolating, 100, 1000, 0, 120 BZ, 4);
    AllIlks[kObjLoserAnorak]->mToHitModifier = -2;

/*
    shObjectIlk *jetpack =
    NEW_ARMOR(kObjJetpack
        "jetpack", "steel backpack", "jetpack",
        kRed, kObjGenericCloak, kSteel,
        kUsuallyBuggy, 100, kTiny, 5, 1, 0,
        0, kNoEnergy, 0, 500, 0, 300, 10);
    jetpack->mWornIntrinsics |= kFlying;
*/

    /* enum: kObjSuperheroCape */
    NEW_ARMOR(kObjSuperheroCape,
        "superhero cape", "cape", "cape",
        kRed, kObjGenericCloak, kCloth,
        kEnhanceable, 500, kLarge, 2, 2, +2,
        1, 2, kPiercing, 2, 500, 0, 300 BZ, 5);
    AllIlks[kObjSuperheroCape]->mSpeedBoost = 5;

    /* enum: kObjGenericBoots */
    NEW_ARMOR(kObjGenericBoots,
        "pair of boots", "pair of boots", "pair of boots",
        kGray, kObjAnyArmor, kCloth,
        0, 400, kSmall, 20, 10, 0,
        0, 2, kNoEnergy, 0, 0, 0, 0 BZ, ABSTRACT);

    /* enum: kObjSturdyBoots */
    NEW_ARMOR(kObjSturdyBoots,
        "pair of sturdy boots", "pair of boots", "pair of sturdy boots",
        kBrown, kObjGenericBoots, kLeather,
        kPreidentified | kEnhanceable, 400, kSmall, 20, 10, 0,
        0, 2, kNoEnergy, 0, 1000, 0, 25 BZ, 25);

    /* enum: kObjSpaceBoots */
    NEW_ARMOR(kObjSpaceBoots,
        "pair of space boots", "pair of boots", "pair of sealed boots",
        kBrown, kObjGenericBoots, kSteel,
        kEnhanceable | kSealed, 400, kSmall, 20, 10, 0,
        1, 2, kNoEnergy, 0, 1000, 0, 50 BZ, 10);

    /* enum: kObjStormtrooperBoots */
    NEW_ARMOR(kObjStormtrooperBoots,
        "pair of stormtrooper boots", "pair of boots", "pair of plastic boots",
        kWhite, kObjGenericBoots, kPlastic,
        kEnhanceable | kSealed, 3000, kSmall, 20, 10, 0,
        1, 2, kNoEnergy, 0, 1000, 0, 50 BZ, 25);

    /* enum: kObjZealotLegEnhancements */
    NEW_ARMOR(kObjZealotLegEnhancements,
        "pair of zealot leg enhancements", "pair of mechanical leggings",
        "pair of mechanical leggings",
        kBrightYellow, kObjGenericBoots, kGold,
        kEnhanceable | kPowered | kSealed, 800, kSmall, 15, 5, 0,
        0, 2, kNoEnergy, 0, 1000, 0, 800 BZ, 3);
    AllIlks[kObjZealotLegEnhancements]->mSpeedBoost = 10;


    /* enum: kObjGenericJumpsuit */
    NEW_ARMOR(kObjGenericJumpsuit,
        "jumpsuit", "jumpsuit", "jumpsuit",
        kGreen, kObjAnyArmor, kCloth,
        kEnhanceable, 400, kMedium, 20, 10, 0,
        1, 4, kNoEnergy, 0, 5000, 0, 0, ABSTRACT);

    /* enum: kObjOrdinaryJumpsuit */
    n = 0;
    NEW_ARMOR(kObjOrdinaryJumpsuit,
        "ordinary jumpsuit", "jumpsuit", JumpsuitData[n].mDesc,
        JumpsuitData[n].mColor, kObjGenericJumpsuit, kCloth,
        kEnhanceable, 400, kMedium, 20, 10, 0,
        1, 4, kNoEnergy, 0, 5000, 0, 25 BZ, 80);
    ++n;

    /* enum: kObjJanitorUniform */
    NEW_ARMOR(kObjJanitorUniform,
        "janitor uniform", "jumpsuit", JumpsuitData[n].mDesc,
        JumpsuitData[n].mColor, kObjGenericJumpsuit, kCloth,
        kEnhanceable, 400, kMedium, 20, 10, 0,
        1, 4, kNoEnergy, 0, 5000, 0, 25 BZ, 10);
    ++n;

    /* enum: kObjRadiationJumpsuit */
    NEW_ARMOR(kObjRadiationJumpsuit,
        "radiation suit", "jumpsuit", JumpsuitData[n].mDesc,
        JumpsuitData[n].mColor, kObjGenericJumpsuit, kCloth,
        kEnhanceable, 400, kMedium, 20, 10, 0,
        1, 4, kRadiological, 10, 5000, 0, 100 BZ, 40);
    ++n;

    /* enum: kObjChameleonJumpsuit */
    NEW_ARMOR(kObjChameleonJumpsuit,
        "chameleon suit", "jumpsuit", JumpsuitData[n].mDesc,
        JumpsuitData[n].mColor, kObjGenericJumpsuit, kCloth,
        kEnhanceable, 400, kMedium, 20, 10, 0,
        1, 4, kNoEnergy, 0, 5000, 0, 100 BZ, 5);
    AllIlks[kObjChameleonJumpsuit]->mWornIntrinsics |= kCamouflaged;
    ++n;

    /* enum: kObjElvenJumpsuit */
    NEW_ARMOR(kObjElvenJumpsuit,
        "elven jumpsuit", "jumpsuit", "pink jumpsuit",
        kMagenta, kObjGenericJumpsuit, kCloth,
        kEnhanceable, 400, kMedium, 20, 10, +1,
        2, 4, kNoEnergy, 0, 5000, 0, 25 BZ, 15);

    /* enum: kObjReticulanJumpsuit */
    NEW_ARMOR(kObjReticulanJumpsuit,
        "reticulan jumpsuit", "jumpsuit", "silvery jumpsuit",
        kWhite, kObjGenericJumpsuit, kCloth,
        kEnhanceable, 400, kSmall, 20, 10, +1,
        1, 4, kPsychic, 1, 5000, 0, 25 BZ, 3);


    /* enum: kObjGenericArmor */
    NEW_ARMOR(kObjGenericArmor,
        "suit of armor", "suit of armor", "suit of armor",
        kBlack, kObjAnyArmor, kCloth,
        kEnhanceable, 400, kMedium, 20, 10, 0,
        0, 6, kNoEnergy, 0, 5000, 0, 0 BZ, ABSTRACT);

    /* enum: kObjReflecSuit */
    NEW_ARMOR(kObjReflecSuit,
        "suit of reflec armor", "suit of armor", "suit of shiny armor",
        kBrightCyan, kObjGenericArmor, kCloth,
        kEnhanceable, 400, kMedium, 20, 10, 0,
        1, 6, kLaser, 4, 5000, 0, 100 BZ, 80);
    AllIlks[kObjReflecSuit]->mWornIntrinsics |= kReflection;

    /* enum: kObjFootballPads */
    NEW_ARMOR(kObjFootballPads,
        "set of football pads", "uniform", "padded uniform",
        kRed, kObjGenericArmor, kCloth,
        kEnhanceable, 5000, kMedium, 20, 10, 0,
        3, 6, kNoEnergy, 0, 7500, 30, 100 BZ, 3);

    /* enum: kObjPlateArmor */
    NEW_ARMOR(kObjPlateArmor,
        "plate armor", "plate armor", "plate armor",
        kBrown, kObjGenericArmor, kCloth,
        kPreidentified | kEnhanceable, 2000, kMedium, 20, 10, -2,
        4, 6, kNoEnergy, 0, 5000, 0, 75 BZ, 3);

    /* enum: kObjFlakJacket */
    NEW_ARMOR(kObjFlakJacket,
        "flak jacket", "jacket", "combat jacket",
        kBrown, kObjGenericArmor, kCloth,
        kEnhanceable, 2500, kMedium, 20, 10, -1,
        3, 6, kNoEnergy, 0, 5000, 0, 75 BZ, 75);

    /* enum: kObjKevlarJacket */
    NEW_ARMOR(kObjKevlarJacket,
        "kevlar jacket", "jacket", "combat jacket",
        kBrown, kObjGenericArmor, kCloth,
        kEnhanceable, 3500, kMedium, 20, 10, -1,
        3, 6, kPiercing, 3, 5000, 0, 125 BZ, 50);

    /* enum: kObjStormtrooperSuit */
    NEW_ARMOR(kObjStormtrooperSuit,
        "stormtrooper suit", "suit of armor", "suit of plastic armor",
        kWhite, kObjGenericArmor, kPlastic,
        kEnhanceable | kSealed, 10000, kMedium, 20, 10, -2,
        4, 6, kNoEnergy, 0, 7500, 10, 400 BZ, 25);

    /* enum: kObjAquamarinePA */
    NEW_ARMOR(kObjAquamarinePA,
        "aquamarine power armor", "suit of armor", "aqua mechanical armor",
        kBrightCyan, kObjGenericArmor, kPlasteel,
        kEnhanceable | kPowered | kSealed,
        15000, kMedium, 25, 15, -2,
        7, 6, kNoEnergy, 0, 10000, 0, 1500 BZ, 10);

    /* enum: kObjMeanGreenPA */
    NEW_ARMOR(kObjMeanGreenPA,
        "mean green power armor", "suit of armor", "green mechanical armor",
        kGreen, kObjGenericArmor, kPlasteel,
        kEnhanceable | kPowered | kSealed,
        15000, kMedium, 25, 15, -2,
        7, 6, kNoEnergy, 0, 10000, 0, 1500 BZ, 10);

    /* enum: kObjSpaceSuit */
    NEW_ARMOR(kObjSpaceSuit,
        "space suit", "sealed suit", "space suit",
        kWhite, kObjGenericArmor, kSteel,
        kEnhanceable | kPowered | kSealed,
        18000, kMedium, 20, 10, -2,
        4, 6, kNoEnergy, 0, 10000, 100, 800 BZ, 25);

    /* enum: kObjElvenSpaceSuit */
    NEW_ARMOR(kObjElvenSpaceSuit,
        "elven space suit", "sealed suit", "pink space suit",
        kMagenta, kObjGenericArmor, kSteel,
        kEnhanceable | kPowered | kSealed, 10000, kMedium, 20, 10, 0,
        5, 6, kNoEnergy, 0, 10000, 100, 1500 BZ, 5);

    /* enum: kObjElvenExarchArmor */
    NEW_ARMOR(kObjElvenExarchArmor,
        "elven exarch armor", "curvy armor", "pink curvy armor",
        kMagenta, kObjGenericArmor, kBone,
        kEnhanceable | kSealed, 6000, kMedium, 10, 10, +1,
        4, 6, kPsychic, 7, 8000, 0, 1000 BZ, 3);
    AllIlks[kObjElvenExarchArmor]->mSpeedBoost = 10;

    /* enum: kObjElvenCombatArmor */
    NEW_ARMOR(kObjElvenCombatArmor,
        "elven combat armor", "curvy armor", "pink curvy armor",
        kMagenta, kObjGenericArmor, kBone,
        kEnhanceable | kSealed, 4000, kMedium, 15, 15, +1,
        5, 6, kPsychic, 3, 6000, 0, 800 BZ, 6);
    AllIlks[kObjElvenCombatArmor]->mSpeedBoost = 5;

    /* enum: kObjZealotArmor */
    NEW_ARMOR(kObjZealotArmor,
        "zealot power armor", "mechanical armor", "golden mechanical armor",
        kBrightYellow, kObjGenericArmor, kGold,
        kEnhanceable | kPowered | kSealed, 12000, kMedium, 25, 15, +2,
        7, 6, kStunning, 25, 2000, 0, 2000 BZ, 2);

    /* enum: kObjBrotherhoodPA */
    /* This adds +2 to str and -2 to agi. (see ApplyConferredResistances) */
    NEW_ARMOR(kObjBrotherhoodPA,
        "brotherhood power armor", "mechanical armor", "vintage mechanical armor",
        kWhite, kObjGenericArmor, kSteel,
        kEnhanceable | kPowered | kSealed, 18000, kMedium, 15, 25, -2,
        6, 6, kRadiological, 25, 10000, 0, 2000 BZ, 8);

    /* enum: kObjBioArmor */
    NEW_ARMOR(kObjBioArmor,
        "reticulan bio armor", "lump of flesh", "bio armor",
        kRed, kObjGenericArmor, kFleshy,
        kEnhanceable | kPowered, 8000, kMedium, 10, 15, 0,
        3, 6, kParalyzing, 5, 3000, 0, 280 BZ, 3);
    AllIlks[kObjBioArmor]->mWornIntrinsics |= kAutoRegeneration;

    /* enum: kObjMBioArmor0 */
    NEW_ARMOR(kObjMBioArmor0,
        "mutated bio armor", "lump of flesh", "bio armor",
        kGreen, kObjBioArmor, kFleshy,
        kEnhanceable | kPowered | kRadioactive, 8000, kMedium, 10, 15, 0,
        2, 6, kNoEnergy, 0, 3000, 0, 0 BZ, 0);

    /* enum: kObjMBioArmor1 */
    NEW_ARMOR(kObjMBioArmor1,
        "pulsating bio armor", "lump of flesh", "bio armor",
        kBrightGreen, kObjMBioArmor0, kFleshy,
        kEnhanceable | kPowered | kRadioactive, 8000, kMedium, 10, 15, 0,
        4, 6, kParalyzing, 5, 3000, 0, 0 BZ, 0);
    AllIlks[kObjMBioArmor1]->mResistances[kPoisonous] = 2;
    AllIlks[kObjMBioArmor1]->mResistances[kCorrosive] = 10;
    AllIlks[kObjMBioArmor1]->mResistances[kSickening] = 10;
    AllIlks[kObjMBioArmor1]->mResistances[kPlaguing] = 100;

    /* enum: kObjMBioArmor2 */
    NEW_ARMOR(kObjMBioArmor2,
        "glistening bio armor", "lump of flesh", "bio armor",
        kBrightGreen, kObjMBioArmor0, kFleshy,
        kEnhanceable | kPowered | kRadioactive, 8000, kMedium, 10, 15, 0,
        4, 6, kParalyzing, 5, 3000, 0, 0 BZ, 0);
    /* Also: +1 to all attributes. */

    /* enum: kObjEBioArmor1 */
    NEW_ARMOR(kObjEBioArmor1,
        "tough bio armor", "lump of flesh", "bio armor",
        kRed, kObjBioArmor, kFleshy,
        kEnhanceable | kPowered, 9000, kMedium, 10, 15, 0,
        5, 6, kParalyzing, 5, 3000, 0, 540 BZ, 1);
    AllIlks[kObjEBioArmor1]->mWornIntrinsics |= kAutoRegeneration;

    /* enum: kObjEBioArmor2 */
    NEW_ARMOR(kObjEBioArmor2,
        "vigorous bio armor", "lump of flesh", "bio armor",
        kRed, kObjBioArmor, kFleshy,
        kEnhanceable | kPowered, 8000, kMedium, 10, 15, 0,
        3, 6, kParalyzing, 5, 3000, 0, 540 BZ, 1);
    AllIlks[kObjEBioArmor2]->mWornIntrinsics |= kAutoRegeneration;
    AllIlks[kObjEBioArmor2]->mSpeedBoost = 5;
    AllIlks[kObjEBioArmor2]->mToHitModifier = 1;
    /* Also: +2 to agility, +1 to constitution. */

    /* enum: kObjEBioArmor3 */
    NEW_ARMOR(kObjEBioArmor3,
        "psionic bio armor", "lump of flesh", "bio armor",
        kRed, kObjBioArmor, kFleshy,
        kEnhanceable | kPowered, 8000, kMedium, 10, 15, +2,
        3, 6, kParalyzing, 5, 3000, 0, 540 BZ, 1);
    AllIlks[kObjEBioArmor3]->mWornIntrinsics |= kAutoRegeneration;
    AllIlks[kObjEBioArmor3]->mResistances[kPsychic] = 3;
    /* Also: +1 to psionics. */

    /* enum: kObjSBioArmor1 */
    NEW_ARMOR(kObjSBioArmor1,
        "bio carapace", "lump of flesh", "bio armor",
        kRed, kObjEBioArmor1, kFleshy,
        kEnhanceable | kPowered, 12000, kMedium, 10, 15, 0,
        7, 6, kParalyzing, 5, 3000, 0, 1080 BZ, 0);
    AllIlks[kObjSBioArmor1]->mWornIntrinsics |= kAutoRegeneration;
    AllIlks[kObjSBioArmor1]->mResistances[kPiercing] = 5;
    AllIlks[kObjSBioArmor1]->mResistances[kSlashing] = 5;
    AllIlks[kObjSBioArmor1]->mResistances[kConcussive] = 5;
    AllIlks[kObjSBioArmor1]->mResistances[kRadiological] = 5;

    /* enum: kObjSBioArmor2 */
    NEW_ARMOR(kObjSBioArmor2,
        "receptive bio armor", "lump of flesh", "bio armor",
        kRed, kObjEBioArmor1, kFleshy,
        kEnhanceable | kPowered, 8000, kMedium, 10, 15, 0,
        6, 10, kParalyzing, 5, 3000, 0, 1080 BZ, 0);
    AllIlks[kObjSBioArmor2]->mWornIntrinsics |= kAutoRegeneration;

    /* enum: kObjSBioArmor3 */
    NEW_ARMOR(kObjSBioArmor3,
        "zesty bio armor", "lump of flesh", "bio armor",
        kRed, kObjEBioArmor2, kFleshy,
        kEnhanceable | kPowered, 8000, kMedium, 10, 15, 0,
        4, 6, kParalyzing, 5, 3000, 0, 1080 BZ, 0);
    AllIlks[kObjSBioArmor3]->mWornIntrinsics |= kAutoRegeneration;
    AllIlks[kObjSBioArmor3]->mSpeedBoost = 10;
    AllIlks[kObjSBioArmor3]->mToHitModifier = 3;
    /* Also: +2 to agility, +2 to constitution and +1 to dexterity. */

    /* enum: kObjSBioArmor4 */
    NEW_ARMOR(kObjSBioArmor4,
        "sentient bio mass", "lump of flesh", "bio armor",
        kRed, kObjEBioArmor3, kFleshy,
        kEnhanceable | kPowered, 8000, kMedium, 10, 15, +2,
        3, 6, kParalyzing, 5, 3000, 0, 1080 BZ, 0);
    AllIlks[kObjSBioArmor4]->mWornIntrinsics |= kAutoRegeneration;
    AllIlks[kObjSBioArmor4]->mResistances[kPsychic] = 8;
    /* Also: +2 to psionics. */
    /* Also: Bonuses to various psionic skills. */
    /* Also: Behaves like psionic amplifier. */

    /* enum: kObjGenericCPA */
    NEW_ARMOR(kObjGenericCPA,
        "chaos power armor", "chaos power armor", "chaos power armor",
        kGray, kObjGenericArmor, kPlasteel,
        kEnhanceable | kPowered | kSealed, 15000, kMedium, 0, 0, 0,
        0, 6, kNoEnergy, 0, 0, 0, 0 BZ, ABSTRACT);

    /* enum: kObjRedCPA */
    NEW_ARMOR(kObjRedCPA,
        "red chaos power armor", "suit of armor", "red riveted armor",
        kBrightRed, kObjGenericCPA, kPlasteel,
        kEnhanceable | kPowered | kSealed, 15000, kMedium, 25, 15, -3,
        7, 6, kBurning, 10, 10000, 10, 2500 BZ, 3);
    AllIlks[kObjRedCPA]->mResistances[kStunning] = 2;
    AllIlks[kObjRedCPA]->mSpeedBoost = +10;
    AllIlks[kObjRedCPA]->mDamageModifier = 3;
    AllIlks[kObjRedCPA]->mToHitModifier = -1;

    /* enum: kObjPinkCPA */
    NEW_ARMOR(kObjPinkCPA,
        "pink chaos power armor", "suit of armor", "pink ornate armor",
        kMagenta, kObjGenericCPA, kPlasteel,
        kEnhanceable | kPowered | kSealed, 15000, kMedium, 25, 15, -2,
        7, 6, kLaser, 10, 10000, 10, 2500 BZ, 3);
    AllIlks[kObjPinkCPA]->mSpeedBoost = +20;
    AllIlks[kObjPinkCPA]->mDamageModifier = -2;
    AllIlks[kObjPinkCPA]->mToHitModifier = 3;

    /* enum: kObjBlueCPA */
    NEW_ARMOR(kObjBlueCPA,
        "blue chaos power armor", "suit of armor", "blue glowing armor",
        kBrightBlue, kObjGenericCPA, kPlasteel,
        kEnhanceable | kPowered | kSealed, 15000, kMedium, 25, 15, +5,
        7, 6, kPsychic, 20, 10000, 0, 2500 BZ, 3);
    AllIlks[kObjBlueCPA]->mWornIntrinsics |= kXRayVision;
    AllIlks[kObjBlueCPA]->mDamageModifier = -1;
    AllIlks[kObjBlueCPA]->mToHitModifier = -1;


    /* enum: kObjGreenCPA */
    /* enum: kObjLastArmor = kObjGreenCPA */
    NEW_ARMOR(kObjGreenCPA,
        "green chaos power armor", "suit of armor", "green sickly armor",
        kGreen, kObjGenericCPA, kPlasteel,
        kEnhanceable | kPowered | kSealed, 20000, kMedium, 25, 15, -2,
        8, 6, kPoisonous, 20, 15000, 10, 2500 BZ, 3);
    AllIlks[kObjGreenCPA]->mResistances[kSickening] = 3;
    AllIlks[kObjGreenCPA]->mWornIntrinsics |= kAutoRegeneration;
    AllIlks[kObjGreenCPA]->mDamageModifier = -1;
    AllIlks[kObjGreenCPA]->mToHitModifier = -1;
    AllIlks[kObjGreenCPA]->mSpeedBoost = -5;
}
